==> geiger_localstorage-0.6.45.tar.gz: lib/src/storage_exception.dart <==
import 'dart:async';

import 'package:geiger_localstorage/geiger_localstorage.dart';

class SerializedException with Exception implements Serializer {
  static const int serialversionUID = 721364991234;

  String _name = "SerializedExceptionUnInited";

  String get name {
    return _name;
  }

  late String _message;

  String get message {
    return _message;
  }

  late StackTrace _stackTrace;

  StackTrace get stackTrace {
    return _stackTrace;
  }

  SerializedException? _cause;

  SerializedException? get cause {
    return _cause;
  }

  SerializedException(name,
      {String message = '',
      StackTrace? stackTrace,
      Exception? cause,
      StackTrace? causeStackTrace}) {
    _name = name;
    _message = message;
    _stackTrace = stackTrace ?? StackTrace.current;
    if (cause != null) {
      if (cause is! SerializedException) {
        cause = SerializedException.fromException(cause,
            stackTrace: causeStackTrace);
      }
      _cause = cause;
    }
  }

  SerializedException.fromException(Exception exception,
      {String? message,
      StackTrace? stackTrace,
      Exception? cause,
      StackTrace? causeStackTrace})
      : this(exception.toString(),
            message: message ?? exception.toString(),
            stackTrace: stackTrace,
            cause: cause,
            causeStackTrace: causeStackTrace);

  @override
  void toByteArrayStream(ByteSink out) {
    SerializerHelper.writeLong(out, serialversionUID);
    SerializerHelper.writeString(out, _name);
    SerializerHelper.writeString(out, _message);
    SerializerHelper.writeString(out, _stackTrace.toString());
    if (_cause != null) {
      SerializerHelper.writeInt(out, 1);
      _cause!.toByteArrayStream(out);
    } else {
      SerializerHelper.writeInt(out, 0);
    }
    SerializerHelper.writeLong(out, serialversionUID);
  }

  static Future<SerializedException> fromByteArrayStream(ByteStream in_) async {
    SerializerHelper.castTest('SerializedException', serialversionUID,
        await SerializerHelper.readLong(in_));
    String name = await SerializerHelper.readString(in_) ?? 'UNKNOWN TEXT';
    String message =
        await SerializerHelper.readString(in_) ?? 'UNKNOWN MESSAGE';

    StackTrace ste =
        StackTrace.fromString(await SerializerHelper.readString(in_) ?? '');

    SerializedException? cause;
    if (await SerializerHelper.readInt(in_) == 1) {
      cause = await SerializedException.fromByteArrayStream(in_);
    }
    SerializerHelper.castTest('SerializedException', serialversionUID,
        await SerializerHelper.readLong(in_), 2);
    return SerializedException(name,
        message: message, stackTrace: ste, cause: cause);
  }

  @override
  String toString() {
    String ret = '$_name:$_message';
    ret += ' at \n${_stackTrace.toString()}';
    if (_cause != null) {
      ret += '\ncause:\n${_cause.toString()}';
    }
    return ret;
  }
}

class StorageException extends SerializedException implements Serializer {
  /// Exception to be raised on any problems related to the local storage.
  static const int serialversionUID = 178324938;

  /// Creates a StorageException with message and root cause.
  ///
  /// A storageException contains always a descriptive string [message] and may
  /// contain additional information such as another exception [cause] and a
  /// [stackTrace].
  StorageException(String message,
      [StackTrace? stackTrace, Exception? cause, StackTrace? causeStackTrace])
      : super('StorageException',
            message: message, cause: cause, causeStackTrace: causeStackTrace);

  StorageException.fromSerializedException(SerializedException e)
      : super('StorageException',
            message: e._message,
            stackTrace: e._stackTrace,
            cause: e._cause,
            causeStackTrace: e._stackTrace);
}

==> geiger_localstorage-0.8.2.tar.gz: lib/src/storage_exception.dart <==
import 'dart:async';

import 'package:geiger_localstorage/geiger_localstorage.dart';

class SerializedException with Exception implements Serializer {
  static const int serialversionUID = 721364991234;

  String _name = "SerializedExceptionUnInited";

  String get name {
    return _name;
  }

  late String _message;

  String get message {
    return _message;
  }

  late StackTrace _stackTrace;

  StackTrace get stackTrace {
    return _stackTrace;
  }

  SerializedException? _cause;

  SerializedException? get cause {
    return _cause;
  }

  SerializedException(name,
      {String message = '',
      StackTrace? stackTrace,
      Exception? cause,
      StackTrace? causeStackTrace}) {
    _name = name;
    _message = message;
    _stackTrace = stackTrace ?? StackTrace.current;
    if (cause != null) {
      if (cause is! SerializedException) {
        cause = SerializedException.fromException(cause,
            stackTrace: causeStackTrace);
      }
      _cause = cause;
    }
  }

  SerializedException.fromException(Exception exception,
      {String? message,
      StackTrace? stackTrace,
      Exception? cause,
      StackTrace? causeStackTrace})
      : this(exception.toString(),
            message: message ?? exception.toString(),
            stackTrace: stackTrace,
            cause: cause,
            causeStackTrace: causeStackTrace);

  @override
  void toByteArrayStream(ByteSink out) {
    SerializerHelper.writeLong(out, serialversionUID);
    SerializerHelper.writeString(out, _name);
    SerializerHelper.writeString(out, _message);
    SerializerHelper.writeStackTraces(out, _stackTrace);
    if (_cause != null) {
      SerializerHelper.writeInt(out, 1);
      _cause!.toByteArrayStream(out);
    } else {
      SerializerHelper.writeInt(out, 0);
    }
    SerializerHelper.writeLong(out, serialversionUID);
  }

  static Future<SerializedException> fromByteArrayStream(ByteStream in_) async {
    SerializerHelper.castTest('SerializedException', serialversionUID,
        await SerializerHelper.readLong(in_));
    String name = await SerializerHelper.readString(in_) ?? 'UNKNOWN TEXT';
    String message =
        await SerializerHelper.readString(in_) ?? 'UNKNOWN MESSAGE';

    StackTrace? ste = await SerializerHelper.readStackTraces(in_);

    SerializedException? cause;
    if (await SerializerHelper.readInt(in_) == 1) {
      cause = await SerializedException.fromByteArrayStream(in_);
    }
    SerializerHelper.castTest('SerializedException', serialversionUID,
        await SerializerHelper.readLong(in_), 2);
    return SerializedException(name,
        message: message, stackTrace: ste, cause: cause);
  }

  @override
  String toString() {
    String ret = '$_name:$_message';
    ret += ' at \n${_stackTrace.toString()}';
    if (_cause != null) {
      ret += '\ncause:\n${_cause.toString()}';
    }
    return ret;
  }
}

class StorageException extends SerializedException implements Serializer {
  /// Exception to be raised on any problems related to the local storage.
  static const int serialversionUID = 178324938;

  /// Creates a StorageException with message and root cause.
  ///
  /// A storageException contains always a descriptive string [message] and may
  /// contain additional information such as another exception [cause] and a
  /// [stackTrace].
  StorageException(String message,
      [StackTrace? stackTrace, Exception? cause, StackTrace? causeStackTrace])
      : super('StorageException',
            message: message, cause: cause, causeStackTrace: causeStackTrace);

  StorageException.fromSerializedException(SerializedException e)
      : super('StorageException',
            message: e._message,
            stackTrace: e._stackTrace,
            cause: e._cause,
            causeStackTrace: e._stackTrace);
}
